@@ -26,10 +26,10 @@ sub get_symbol_from_doc
         {
         my $pos = pos ($data) ;
         my $len = length ($1) ;
-        print STDERR "word: <$1> pos: $pos len: $len\n" ;
+        $self -> logger ("word: <$1> pos: $pos len: $len\n") if ($Perl::LanguageServer::debug2) ;
         if ($char <= $pos && $char >= $pos - $len)
             {
-            print STDERR "ok\n" ;
+            $self -> logger ("ok\n") if ($Perl::LanguageServer::debug2) ;
             return $1 ;
             }
         }
